Menu

Struct Menu 

pub struct Menu { /* private fields */ }
The Menu to be shown in the command line interface.

Implementations

Source

impl Menu

pub fn new(options: Vec<MenuOption>) -> Menu

Creates a new interactable Menu.

Examples
fn action_example() {}
let menu_option = MenuOption::new("Option example", action_example);
let menu = Menu::new(vec![menu_option]);

You can use closures to easily use arguments in your functions.

fn action_example(msg: &str, val: f32) {
    println!("action 3 with string {} and float {}", msg, val)
}
let menu_option = MenuOption::new("Option example", || action_example("example", 3.514));
let menu = Menu::new(vec![menu_option]);
pub fn title(self, text: &str) -> Menu

Sets a title for the menu.

Example
fn action_example() {}
let menu_option = MenuOption::new("Option example", action_example);
let menu = Menu::new(vec![menu_option]).title("Title example");
pub fn show(self)

Shows the menu in the command line interface allowing the user to interact with the menu.