Struct menu_rs::Menu

source ·
pub struct Menu { /* private fields */ }
The Menu to be shown in the command line interface.

Implementations

Creates a new interactable Menu.

Example
fn action_example() {}
let menu_option = MenuOption::new("Option example", action_example);

Shows the menu in the command line interface allowing the user to interact with the menu.