pub struct Menu { /* private fields */ }
The Menu to be shown in the command line interface.
Creates a new interactable Menu.
fn action_example() {}
let menu_option = MenuOption::new("Option example", action_example);
Shows the menu in the command line interface allowing the user
to interact with the menu.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.